<p align="center">
    <img src="https://raw.githubusercontent.com/speckai/speck/main/assets/speck_banner.jpg">
</p>
<p align="center">
    <a href="https://pypi.org/project/speck/">
        <img src="https://img.shields.io/pypi/dm/speck" />
    </a>
    <a href="https://discord.com/invite/frnaYYaKj3">
        <img src="https://dcbadge.vercel.app/api/server/frnaYYaKj3?style=flat" />
    </a>
    <a href="https://github.com/speckai/speck">
        <img src="https://img.shields.io/github/commit-activity/m/speckai/speck" />
    </a>
</p>

---

<b>Speck</b> is an LLM debugging and observability platform. Prompt engineer, A/B test, and track your production LLM app metrics in one place.

### Features

- Unified model input/output format
- LLM and app log tracking

---

## Getting Started

### Python

```shell
pip install speck
```

---

## Background

Monitoring LLM apps in production isn't easy.

---

## Development

### Installing Latest Version

```shell
pip3 install --upgrade git+https://github.com/speckai/speck.git#subdirectory=src/python
```
